aboutsummaryrefslogtreecommitdiffstats
path: root/arch/arm/mach-imx/cpuidle-imx6q.c
diff options
context:
space:
mode:
authorFabio Estevam <fabio.estevam@freescale.com>2014-01-07 08:00:40 -0200
committerShawn Guo <shawn.guo@linaro.org>2014-03-05 10:34:59 +0800
commitfa6be65ed4d65ca7e56a878d247ed963a3619c0e (patch)
treefd9a5b1715952569d050326ad0f36292399bff9e /arch/arm/mach-imx/cpuidle-imx6q.c
parentARM: imx_v6_v7_defconfig: Select PCI support (diff)
downloadlinux-dev-fa6be65ed4d65ca7e56a878d247ed963a3619c0e.tar.xz
linux-dev-fa6be65ed4d65ca7e56a878d247ed963a3619c0e.zip
ARM: imx: Use INT_MEM_CLK_LPM as the bit name
Bit 17 of register CCM_CGPR is called INT_MEM_CLK_LPM as per the mx6 reference manual, so use this name instead. Signed-off-by: Fabio Estevam <fabio.estevam@freescale.com> Signed-off-by: Shawn Guo <shawn.guo@linaro.org>
Diffstat (limited to 'arch/arm/mach-imx/cpuidle-imx6q.c')
-rw-r--r--arch/arm/mach-imx/cpuidle-imx6q.c4
1 files changed, 2 insertions, 2 deletions
diff --git a/arch/arm/mach-imx/cpuidle-imx6q.c b/arch/arm/mach-imx/cpuidle-imx6q.c
index 23ddfb693b2d..6bcae0479049 100644
--- a/arch/arm/mach-imx/cpuidle-imx6q.c
+++ b/arch/arm/mach-imx/cpuidle-imx6q.c
@@ -68,8 +68,8 @@ int __init imx6q_cpuidle_init(void)
/* Need to enable SCU standby for entering WAIT modes */
imx_scu_standby_enable();
- /* Set chicken bit to get a reliable WAIT mode support */
- imx6q_set_chicken_bit();
+ /* Set INT_MEM_CLK_LPM bit to get a reliable WAIT mode support */
+ imx6q_set_int_mem_clk_lpm();
return cpuidle_register(&imx6q_cpuidle_driver, NULL);
}